package de.swingbe.ifleet;

import de.swingbe.ifleet.model.*;
import de.swingbe.ifleet.parser.EntyParserFactory;
import org.junit.jupiter.api.Test;

import static org.assertj.core.api.Assertions.assertThat;

/**
 * Test telegram parsing.
 * <p>
 * Note that this class is package-private, so that the client can not use it.
 */
class TelegrParserImplTest {

    private final Enty eSendLctMsg = new Enty("2021-11-30", "11:24:13,438", "INFO", "BON", "195.30.103.89:58713", "(NpmTCPAcceptedChannel)", "(195.30.103.89:58713)", "sent", new Comm(new Header(new Sender("I", "WOL/234"), new Receiver("B", "")), new Telegr(new TelegramHdr("1", "1.8", "1"), new TcLctMsg("1", new Position("1501303H", "280", "87263783", "529019052", "0", "420", "162"), "29", new Trip("711", "1101", "1101099", "", "452", "0", "2", "2")))));
    private final String strSendLctMsg = "2021-11-30 11:24:13,438 INFO  [BON /195.30.103.89:58713] (NpmTCPAcceptedChannel) (/195.30.103.89:58713) sent <I#WOL/234#B##1#1.8#1#1501303H#280#87263783#529019052#0#420#162#29#711#1101#1101099##452#0#2#37500#0#6.>";
    private final Enty eFromStrSendLctMsg = EntyParserFactory.createEntyParser().parse(strSendLctMsg);

    @Test
    void getDate() {
        assertThat(eFromStrSendLctMsg.getDate()).isEqualTo(eSendLctMsg.getDate());
    }

    @Test
    void getTime() {
        assertThat(eFromStrSendLctMsg.getTime()).isEqualTo(eSendLctMsg.getTime());
    }

    @Test
    void getLogLevel() {
        assertThat(eFromStrSendLctMsg.getLogLevel()).isEqualTo(eSendLctMsg.getLogLevel());
    }

    @Test
    void getAddressPartA() {
        assertThat(eFromStrSendLctMsg.getAddressPartA()).isEqualTo(eSendLctMsg.getAddressPartA());
    }

    @Test
    void parse() {
        assertThat(eFromStrSendLctMsg).isEqualTo(eSendLctMsg);
    }

    @Test
    void getAddressPartB() {
        assertThat(eFromStrSendLctMsg.getAddressPartB()).isEqualTo(eSendLctMsg.getAddressPartB());
    }

    @Test
    void getPeer() {
        assertThat(eFromStrSendLctMsg.getPeer()).isEqualTo(eSendLctMsg.getPeer());
    }

    @Test
    void getAddressNext() {
        assertThat(eFromStrSendLctMsg.getAddressNext()).isEqualTo(eSendLctMsg.getAddressNext());
    }

    @Test
    void getDirection() {
        assertThat(eFromStrSendLctMsg.getDirection()).isEqualTo(eSendLctMsg.getDirection());
    }

    @Test
    void getSenderTyp() {
        assertThat(eFromStrSendLctMsg.getComm().getHeader().getSender().getType()).isEqualTo(eSendLctMsg.getComm().getHeader().getSender().getType());
    }

    @Test
    void getSenderId() {
        assertThat(eFromStrSendLctMsg.getComm().getHeader().getSender().getId()).isEqualTo(eSendLctMsg.getComm().getHeader().getSender().getId());
    }

    @Test
    void getReceiverTyp() {
        assertThat(eFromStrSendLctMsg.getComm().getHeader().getReceiver().getType()).isEqualTo(eSendLctMsg.getComm().getHeader().getReceiver().getType());
    }

    @Test
    void getReceiverId() {
        assertThat(eFromStrSendLctMsg.getComm().getHeader().getReceiver().getId()).isEqualTo(eSendLctMsg.getComm().getHeader().getReceiver().getId());
    }

    @Test
    void getTeleType() {
        assertThat(eFromStrSendLctMsg.getComm().getTelegr().getTeleHeader().getTeleType()).isEqualTo(eSendLctMsg.getComm().getTelegr().getTeleHeader().getTeleType());
    }

    @Test
    void getTeleId() {
        assertThat(eFromStrSendLctMsg.getComm().getTelegr().getTeleHeader().getTeleId()).isEqualTo(eSendLctMsg.getComm().getTelegr().getTeleHeader().getTeleId());
    }
}
